=== modified file 'NEWS'
--- NEWS	2005-09-12 09:47:33 +0000
+++ NEWS	2005-09-13 23:42:32 +0000
@@ -8,6 +8,9 @@
       get added when you add a file in the directory.  Contributed by
       Michael Ellerman.
 
+    * Ignore .DS_Store (contains Mac metadata) by default.  Patch from
+      Nir Soffer.
+
 
   INTERNALS:
 

=== modified file 'bzrlib/__init__.py'
--- bzrlib/__init__.py	2005-09-09 11:37:44 +0000
+++ bzrlib/__init__.py	2005-09-16 03:32:44 +0000
@@ -28,7 +28,8 @@
                   'BitKeeper',
                   '.git',
                   'TAGS', '.make.state', '.sconsign', '.tmp*',
-                  '.del-*']
+                  '.del-*',
+                  '.DS_Store',]
 
 IGNORE_FILENAME = ".bzrignore"
 

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2005-09-15 15:16:12 +0000
+++ bzrlib/builtins.py	2005-09-16 10:45:59 +0000
@@ -1295,14 +1295,13 @@
                     print "Using last location: %s" % parent
                 remote = parent
         elif parent is None:
-            # We only update parent if it did not exist, missing should not change the parent
+            # We only update parent if it did not exist, missing
+            # should not change the parent
             b.set_parent(remote)
         br_remote = Branch.open_containing(remote)
-
         return show_missing(b, br_remote, verbose=verbose, quiet=quiet)
 
 
-
 class cmd_plugins(Command):
     """List plugins"""
     hidden = True

=== modified file 'bzrlib/help.py'
--- bzrlib/help.py	2005-09-06 11:09:03 +0000
+++ bzrlib/help.py	2005-09-16 03:32:44 +0000
@@ -30,24 +30,24 @@
 
 Basic commands:
 
-  bzr init      makes this branch versioned
-  bzr branch    make a copy of another branch
-
-  bzr add       make files or directories versioned
-  bzr ignore    ignore a file or pattern
-  bzr mv        move or rename a versioned file
-
-  bzr status    summarize changes in working copy
-  bzr diff      show detailed diffs
-
-  bzr merge     pull in changes from another branch
-  bzr commit    save some or all changes
-
-  bzr log       show history of changes
-  bzr check     validate storage
-
-Use e.g. 'bzr help init' for more details, or
-'bzr help commands' for all commands.
+  bzr init           makes this directory a versioned branch
+  bzr branch         make a copy of another branch
+
+  bzr add            make files or directories versioned
+  bzr ignore         ignore a file or pattern
+  bzr mv             move or rename a versioned file
+
+  bzr status         summarize changes in working copy
+  bzr diff           show detailed diffs
+
+  bzr merge          pull in changes from another branch
+  bzr commit         save some or all changes
+
+  bzr log            show history of changes
+  bzr check          validate storage
+
+  bzr help init      more help on e.g. init command
+  bzr help commands  list all commands
 """
 
 

=== modified file 'bzrlib/selftest/__init__.py'
--- bzrlib/selftest/__init__.py	2005-09-14 18:07:16 +0000
+++ bzrlib/selftest/__init__.py	2005-09-16 03:32:44 +0000
@@ -20,9 +20,11 @@
 import tempfile
 import os
 import sys
+import errno
 import subprocess
+import shutil
 
-from testsweet import run_suite
+import testsweet
 import bzrlib.commands
 
 import bzrlib.trace
@@ -188,17 +190,22 @@
             self.fail("contents of %s not as expected")
 
     def _make_test_root(self):
-        import os
-        import shutil
-        import tempfile
-        
         if TestCaseInTempDir.TEST_ROOT is not None:
             return
-        TestCaseInTempDir.TEST_ROOT = os.path.abspath(
-                                 tempfile.mkdtemp(suffix='.tmp',
-                                                  prefix=self._TEST_NAME + '-',
-                                                  dir=os.curdir))
-    
+        i = 0
+        while True:
+            root = 'test%04d.tmp' % i
+            try:
+                os.mkdir(root)
+            except OSError, e:
+                if e.errno == errno.EEXIST:
+                    i += 1
+                    continue
+                else:
+                    raise
+            # successfully created
+            TestCaseInTempDir.TEST_ROOT = os.path.abspath(root)
+            break
         # make a fake bzr directory there to prevent any tests propagating
         # up onto the source directory's real branch
         os.mkdir(os.path.join(TestCaseInTempDir.TEST_ROOT, '.bzr'))
@@ -292,7 +299,7 @@
 
 
 def selftest(verbose=False, pattern=".*"):
-    return run_suite(test_suite(), 'testbzr', verbose=verbose, pattern=pattern)
+    return testsweet.run_suite(test_suite(), 'testbzr', verbose=verbose, pattern=pattern)
 
 
 def test_suite():

=== modified file 'bzrlib/selftest/testrevisionnamespaces.py'
--- bzrlib/selftest/testrevisionnamespaces.py	2005-09-15 15:16:12 +0000
+++ bzrlib/selftest/testrevisionnamespaces.py	2005-09-16 03:38:22 +0000
@@ -22,7 +22,9 @@
 
 class TestRevisionNamespaces(TestCaseInTempDir):
     def test_revision_namespaces(self):
-        """Functional tests for hashcache"""
+        """Test revision specifiers.
+
+        These identify revisions by date, etc."""
         from bzrlib.errors import NoSuchRevision
         from bzrlib.branch import Branch
         from bzrlib.revisionspec import RevisionSpec

